execFallbackAsync method

Future execFallbackAsync(
  1. dynamic prepResult,
  2. Exception error
)

Async fallback method for when execAsync fails after all retries.

The prepResult is the result from the prepAsync method, and the error is the exception that was caught during the last attempt of the execAsync method.

The default implementation re-throws the error.

Implementation

Future<dynamic> execFallbackAsync(dynamic prepResult, Exception error) async {
  throw error;
}