execAsyncItem method
Processes a single item asynchronously.
This method should be overridden in subclasses to define the processing logic for each individual item. The base class will call this method for each item in parallel.
If a function was provided to the constructor, it will be used instead.
Note: This method has a different signature than the parent's execAsync because it processes individual items, not the entire prep result.
Implementation
Future<O> execAsyncItem(I item) async {
if (_execFunction != null) {
return _execFunction(item);
}
throw UnimplementedError(
'execAsyncItem must be overridden in subclasses or a function must be '
'provided to the constructor.',
);
}