exec method

Future exec(
  1. dynamic prepResult
)

The main execution logic for the node.

This method is called after the prep method. It should contain the main logic for the node. The prepResult is the value returned by the prep method.

Returns a value that will be passed to the post method.

Implementation

Future<dynamic> exec(dynamic prepResult) async {
  // Default implementation does nothing.
}