prep method

Future prep(
  1. Map<String, dynamic> shared
)

Pre-processing logic before exec.

This method is called before the exec method. It can be used to prepare data for the exec method. The shared map contains data that is shared across all nodes in the workflow.

Returns a value that will be passed to the exec method.

Implementation

Future<dynamic> prep(Map<String, dynamic> shared) async {
  // Default implementation does nothing.
}