createInstance method

  1. @override
BaseNode createInstance()
override

Creates a new instance of Node with the same constructor parameters.

This factory method is used by the base clone() method to create a new instance of the correct type.

Implementation

@override
/// Creates a new instance of Node with the same constructor parameters.
///
/// This factory method is used by the base clone() method to create
/// a new instance of the correct type.
BaseNode createInstance() {
  return Node(
    maxRetries: maxRetries,
    wait: wait,
  );
}