exec method

  1. @override
Future<O> exec(
  1. covariant I item
)
override

The main execution logic for processing a single item.

This method is intended to be implemented by subclasses to define the specific processing logic for a single item. The item parameter is a single item to be processed, and the method should return a processed item.

Implementation

@override
Future<O> exec(covariant I item) async {
  throw UnimplementedError('exec must be implemented by a subclass.');
}