post method
Post-processing logic after exec.
This method is called after the exec method. It can be used to process
the result of the exec method and update the shared map. The
prepResult is the value returned by the prep method, and the
execResult is the value returned by the exec method.
Returns a value that will be returned by the run method.
Implementation
Future<dynamic> post(
Map<String, dynamic> shared,
dynamic prepResult,
dynamic execResult,
) async {
// Default implementation returns the execution result.
return execResult;
}