exec method
The main execution logic for the flow.
This method implements Python's Flow pattern where exec calls _orch. It orchestrates the execution of the flow graph using the orch method.
Matches Python's pattern:
def _run(self,shared):
p=self.prep(shared); o=self._orch(shared)
return self.post(shared,p,o)
Implementation
@override
/// The main execution logic for the flow.
///
/// This method implements Python's Flow pattern where exec calls _orch.
/// It orchestrates the execution of the flow graph using the orch method.
///
/// Matches Python's pattern:
/// ```python
/// def _run(self,shared):
/// p=self.prep(shared); o=self._orch(shared)
/// return self.post(shared,p,o)
/// ```
Future<dynamic> exec(dynamic prepResult) async {
return orch(shared);
}